Crate micrortu_ie_representation_derive

Crate micrortu_ie_representation_derive 

Macros

finalize
Finalize the build process. That macro must be called at the end to embed metadata into the binary. It creates a link section “metadata” with json data of all registered blocks and exported symbol COLLECTED_STRINGS with all strings from the build. BindingDefinition’s name_offset and name_len are referencing COLLECTED_STRINGS.
params
Macros for generating parser of arguments block requires.
ports
Macros for generating parser of arguments block requires.
register_block
Register block. That macro should be called for each block to register it.

Derive Macros

Config
Derive macro for Config trait.